Learn R Programming

RobinCar2 (version 0.1.1)

h_get_vars: Extract Variable Names

Description

Extract Variable Names

Usage

h_get_vars(treatment)

Value

A list of three elements, treatment, schema and strata.

Arguments

treatment

(string or formula) string name of the treatment, or a formula.

Details

Extract the formula elements, including treatment, schema and strata.