powered by
Extract Variable Names
h_get_vars(treatment)
A list of three elements, treatment, schema and strata.
treatment
schema
strata
(string or formula) string name of the treatment, or a formula.
string
formula
Extract the formula elements, including treatment, schema and strata.